Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(95)

Unified Diff: components/offline_pages/core/snapshot_controller.h

Issue 2797013002: [Offline pages] Update background loader to override the WebContentsObserver methods expected (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/core/snapshot_controller.h
diff --git a/components/offline_pages/core/snapshot_controller.h b/components/offline_pages/core/snapshot_controller.h
index 36e1680a6f03f515a7c0305eef0669a6602796d6..b02de524f886d85afc0a6ad4d188dfa98fb4cf2a 100644
--- a/components/offline_pages/core/snapshot_controller.h
+++ b/components/offline_pages/core/snapshot_controller.h
@@ -82,14 +82,23 @@ class SnapshotController {
// now completed (so the next one can be started).
void PendingSnapshotCompleted();
- // Invoked from WebContentObserver::DocumentAvailableInMainFrame
+ // Invoked from WebContentsObserver::DocumentLoadedInFrame when the frame
+ // is the main frame.
+ void DocumentLoadedInMainFrame();
+
+ // Invoked from WebContentsObserver::DidStopLoading.
+ void DidStopLoading();
+
+ // Invoked from WebContentsObserver::DocumentAvailableInMainFrame.
+ // Maps to DocumentLoadedInMainFrame for now.
void DocumentAvailableInMainFrame();
// Invoked from WebContentObserver::DocumentOnLoadCompletedInMainFrame
void DocumentOnLoadCompletedInMainFrame();
- int64_t GetDelayAfterDocumentAvailableForTest();
- int64_t GetDelayAfterDocumentOnLoadCompletedForTest();
+ int64_t GetDelayAfterDocumentLoadedForTest();
+ int64_t GetDelayAfterLoadCompletedForTest();
PageQuality current_page_quality() const { return current_page_quality_; }
@@ -101,8 +110,8 @@ class SnapshotController {
// Client owns this class.
SnapshotController::Client* client_;
SnapshotController::State state_;
- int64_t delay_after_document_available_ms_;
- int64_t delay_after_document_on_load_completed_ms_;
+ int64_t delay_after_document_loaded_ms_;
+ int64_t delay_after_load_completed_ms_;
// The expected quality of a snapshot taken at the moment this value is
// queried.
@@ -82,14 +82,23 @@ class SnapshotController {
void DocumentAvailableInMainFrame();
- // Invoked from WebContentObserver::DocumentOnLoadCompletedInMainFrame
+ // Invoked from WebContentsObserver::DocumentOnLoadCompletedInMainFrame.
+ // Maps to DidStopLoading for now.
void DocumentOnLoadCompletedInMainFrame();

Powered by Google App Engine
This is Rietveld 408576698